package com.ruoyi.system.service.impl;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.system.domain.SysProject;
import com.ruoyi.system.mapper.SysProjectMapper;
import com.ruoyi.system.mapper.SysSecretProjectMapper;
import com.ruoyi.system.service.ISysProjectService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 【请填写功能名称】Service业务层处理
 *
 * @author ruoyi
 * @date 2023-11-20
 */
@Service
public class SysProjectServiceImpl implements ISysProjectService {

    @Autowired
    private SysProjectMapper sysProjectMapper;
    @Autowired
    private SysSecretProjectMapper sysSecretProjectMapper;

    /**
     * 查询【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    @Override
    public SysProject selectSysProjectById(Long id) {
        return sysProjectMapper.selectSysProjectById(id);
    }

    /**
     * 查询【请填写功能名称】列表
     *
     * @param sysProject 【请填写功能名称】
     * @return 【请填写功能名称】
     */
    @Override
    public List<SysProject> selectSysProjectList(SysProject sysProject) {
        return sysProjectMapper.selectSysProjectList(sysProject);
    }

    /**
     * 新增【请填写功能名称】
     *
     * @param sysProject 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int insertSysProject(SysProject sysProject) {
        return sysProjectMapper.insertSysProject(sysProject);
    }

    /**
     * 修改【请填写功能名称】
     *
     * @param sysProject 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int updateSysProject(SysProject sysProject) {
        return sysProjectMapper.updateSysProject(sysProject);
    }

    /**
     * 批量删除【请填写功能名称】
     *
     * @param ids 需要删除的【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public AjaxResult deleteSysProjectByIds(Long[] ids) {
        int i = sysSecretProjectMapper.selectCountByProjectId(ids);
        if (i > 0) {
            return AjaxResult.error("此项目已经授权，请勿删除!");
        } else {
            return AjaxResult.success(sysProjectMapper.deleteSysProjectByIds(ids));
        }
    }

    /**
     * 删除【请填写功能名称】信息
     *
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteSysProjectById(Long id) {
        return sysProjectMapper.deleteSysProjectById(id);
    }

    @Override
    public List<SysProject> selectSysProjectAllList() {
        return sysProjectMapper.selectSysProjectAllList();
    }
}
